package collector

import (
	"math"
	"net/http"
	"strconv"
	"time"
)

// httpClient는 서비스 프로브(HTTP 앱/nginx)용 공용 클라이언트입니다.
var httpClient = &http.Client{Timeout: 8 * time.Second}

func atoiSafe(s string) int64 {
	v, _ := strconv.ParseInt(s, 10, 64)
	return v
}

func atofSafe(s string) float64 {
	v, _ := strconv.ParseFloat(s, 64)
	return v
}

// roundF는 소수점 d자리로 반올림합니다.
func roundF(v float64, d int) float64 {
	p := math.Pow(10, float64(d))
	return math.Round(v*p) / p
}
